@@ -9,8 +9,8 @@
 use super::Client;
 use crate::client::Error;
 use crate::messaging::{
-    data::{DataCmd, DataMsg, ProcessMsg},
-    DataSigned, WireMsg,
+    data::{DataCmd, ServiceMsg},
+    ServiceAuth, WireMsg,
 };
 use crate::types::{PublicKey, Signature};
 use bytes::Bytes;
@@ -28,21 +28,19 @@ impl Client {
         signature: Signature,
     ) -> Result<(), Error> {
         debug!("Sending DataCmd: {:?}", cmd);
-        let data_signed = DataSigned {
+        let auth = ServiceAuth {
             public_key: client_pk,
             signature,
         };
 
-        self.session
-            .send_cmd(cmd, data_signed, serialised_cmd)
-            .await
+        self.session.send_cmd(cmd, auth, serialised_cmd).await
     }
 
     // Send a DataCmd to the network without awaiting for a response.
     // This function is a helper private to this module.
     pub(crate) async fn send_cmd(&self, cmd: DataCmd) -> Result<(), Error> {
         let client_pk = self.public_key();
-        let msg = DataMsg::Process(ProcessMsg::Cmd(cmd.clone()));
+        let msg = ServiceMsg::Cmd(cmd.clone());
         let serialised_cmd = WireMsg::serialize_msg_payload(&msg)?;
         let signature = self.keypair.sign(&serialised_cmd);
 
