@@ -9,8 +9,8 @@
 use super::Client;
 use crate::client::{connections::QueryResult, errors::Error};
 use crate::messaging::{
-    data::{DataMsg, DataQuery, ProcessMsg},
-    DataSigned, WireMsg,
+    data::{DataQuery, ServiceMsg},
+    ServiceAuth, WireMsg,
 };
 use crate::types::{PublicKey, Signature};
 use bytes::Bytes;
@@ -28,21 +28,19 @@ impl Client {
         signature: Signature,
     ) -> Result<QueryResult, Error> {
         debug!("Sending Query: {:?}", query);
-        let data_signed = DataSigned {
+        let auth = ServiceAuth {
             public_key: client_pk,
             signature,
         };
 
-        self.session
-            .send_query(query, data_signed, serialised_query)
-            .await
+        self.session.send_query(query, auth, serialised_query).await
     }
 
     // Send a Query to the network and await a response.
     // This function is a helper private to this module.
     pub(crate) async fn send_query(&self, query: DataQuery) -> Result<QueryResult, Error> {
         let client_pk = self.public_key();
-        let msg = DataMsg::Process(ProcessMsg::Query(query.clone()));
+        let msg = ServiceMsg::Query(query.clone());
         let serialised_query = WireMsg::serialize_msg_payload(&msg)?;
         let signature = self.keypair.sign(&serialised_query);
 
