@@ -11,8 +11,8 @@ mod wire_msg_header;
 
 pub use self::wire_msg::WireMsg;
 use super::{
-    data::DataMsg, node::NodeMsg, section_info::SectionInfoMsg, Authority, BlsShareSigned,
-    DataSigned, DstLocation, MessageId, NodeSigned, SectionSigned,
+    data::ServiceMsg, node::NodeMsg, section_info::SectionInfoMsg, AuthorityProof, BlsShareAuth,
+    DstLocation, MessageId, NodeAuth, SectionAuth, ServiceAuth,
 };
 
 /// Type of message.
@@ -30,16 +30,16 @@ pub enum MessageType {
         /// the message
         msg: SectionInfoMsg,
     },
-    /// Data message
-    Data {
+    /// Service message
+    Service {
         /// Message ID
         msg_id: MessageId,
         /// Requester's authority over this message
-        data_auth: Authority<DataSigned>,
+        auth: AuthorityProof<ServiceAuth>,
         /// Message destination location
         dst_location: DstLocation,
         /// the message
-        msg: DataMsg,
+        msg: ServiceMsg,
     },
     /// Node to node message
     Node {
@@ -59,9 +59,9 @@ pub enum MessageType {
 #[derive(PartialEq, Debug, Clone)]
 pub enum NodeMsgAuthority {
     /// Authority of a single peer.
-    Node(Authority<NodeSigned>),
+    Node(AuthorityProof<NodeAuth>),
     /// Authority of a single peer that uses it's BLS Keyshare to sign the message.
-    BlsShare(Authority<BlsShareSigned>),
+    BlsShare(AuthorityProof<BlsShareAuth>),
     /// Authority of a whole section.
-    Section(Authority<SectionSigned>),
+    Section(AuthorityProof<SectionAuth>),
 }
