@@ -8,9 +8,9 @@
 
 use super::{Mapping, MsgContext};
 use crate::messaging::{
-    data::{DataCmd, DataMsg, ProcessMsg, QueryResponse},
+    data::{DataCmd, QueryResponse, ServiceMsg},
     node::{NodeCmd, NodeMsg, NodeQuery, NodeQueryResponse},
-    Authority, DataSigned, DstLocation, MessageId, SrcLocation, WireMsg,
+    AuthorityProof, DstLocation, MessageId, ServiceAuth, SrcLocation, WireMsg,
 };
 use crate::node::{
     error::convert_to_error_message,
@@ -75,58 +75,47 @@ fn match_node_msg(msg_id: MessageId, msg: MessageReceived, origin: SrcLocation)
         // ------ metadata ------
         MessageReceived::NodeQuery(NodeQuery::Metadata {
             query,
-            data_signed,
+            auth,
             origin: query_origin,
-        }) => {
-            match verify_data_authority(
+        }) => match verify_authority(msg_id, origin, auth, ServiceMsg::Query(query.clone())) {
+            Ok(auth) => NodeDuty::ProcessRead {
+                query,
                 msg_id,
-                origin,
-                data_signed,
-                ProcessMsg::Query(query.clone()),
-            ) {
-                Ok(data_auth) => NodeDuty::ProcessRead {
-                    query,
-                    msg_id,
-                    data_auth,
-                    origin: query_origin,
-                },
-                Err(duty) => duty,
-            }
-        }
+                auth,
+                origin: query_origin,
+            },
+            Err(duty) => duty,
+        },
         MessageReceived::NodeCmd(NodeCmd::Metadata {
             cmd,
-            data_signed,
+            auth,
             origin: cmd_origin,
-        }) => {
-            match verify_data_authority(msg_id, origin, data_signed, ProcessMsg::Cmd(cmd.clone())) {
-                Ok(data_auth) => NodeDuty::ProcessWrite {
-                    cmd,
-                    msg_id,
-                    data_auth,
-                    origin: cmd_origin,
-                },
-                Err(duty) => duty,
-            }
-        }
+        }) => match verify_authority(msg_id, origin, auth, ServiceMsg::Cmd(cmd.clone())) {
+            Ok(auth) => NodeDuty::ProcessWrite {
+                cmd,
+                msg_id,
+                auth,
+                origin: cmd_origin,
+            },
+            Err(duty) => duty,
+        },
         //
         // ------ Adult ------
         MessageReceived::NodeQuery(NodeQuery::Chunks { query, .. }) => NodeDuty::ReadChunk {
             read: query,
             msg_id,
         },
-        MessageReceived::NodeCmd(NodeCmd::Chunks {
-            cmd, data_signed, ..
-        }) => {
-            match verify_data_authority(
+        MessageReceived::NodeCmd(NodeCmd::Chunks { cmd, auth, .. }) => {
+            match verify_authority(
                 msg_id,
                 origin,
-                data_signed,
-                ProcessMsg::Cmd(DataCmd::Chunk(cmd.clone())),
+                auth,
+                ServiceMsg::Cmd(DataCmd::Chunk(cmd.clone())),
             ) {
-                Ok(data_auth) => NodeDuty::WriteChunk {
+                Ok(auth) => NodeDuty::WriteChunk {
                     write: cmd,
                     msg_id,
-                    data_auth,
+                    auth,
                 },
                 Err(duty) => duty,
             }
@@ -162,14 +151,14 @@ fn match_node_msg(msg_id: MessageId, msg: MessageReceived, origin: SrcLocation)
     }
 }
 
-fn verify_data_authority(
+fn verify_authority(
     msg_id: MessageId,
     origin: SrcLocation,
-    data_signed: DataSigned,
-    msg: ProcessMsg,
-) -> Result<Authority<DataSigned>, NodeDuty> {
-    WireMsg::serialize_msg_payload(&DataMsg::Process(msg))
-        .and_then(|payload| Authority::verify(data_signed, &payload))
+    auth: ServiceAuth,
+    msg: ServiceMsg,
+) -> Result<AuthorityProof<ServiceAuth>, NodeDuty> {
+    WireMsg::serialize_msg_payload(&msg)
+        .and_then(|payload| AuthorityProof::verify(auth, &payload))
         .map_err(|error| send_error(msg_id, origin, Error::Message(error), false))
 }
 
