@@ -16,7 +16,7 @@ use crate::{
         data::{
             DataCmd, QueryResponse, RegisterCmd, RegisterDataExchange, RegisterRead, RegisterWrite,
         },
-        Authority, DataSigned,
+        AuthorityProof, ServiceAuth,
     },
     types::DataAddress,
 };
@@ -102,14 +102,11 @@ impl RegisterStorage {
         // todo: make outer loop parallel
         for (_, history) in data {
             for op in history {
-                let data_auth =
-                    super::verify_op(op.client_sig.clone(), DataCmd::Register(op.write.clone()))
-                        .map_err(|_| {
-                            Error::Logic(
-                                "Received register operation signature is invalid".to_string(),
-                            )
-                        })?;
-                let _ = self.apply(op, data_auth)?;
+                let auth = super::verify_op(op.auth.clone(), DataCmd::Register(op.write.clone()))
+                    .map_err(|_| {
+                    Error::Logic("Received register operation signature is invalid".to_string())
+                })?;
+                let _ = self.apply(op, auth)?;
             }
         }
 
@@ -121,7 +118,7 @@ impl RegisterStorage {
     pub(crate) async fn write(
         &self,
         write: RegisterWrite,
-        data_auth: Authority<DataSigned>,
+        auth: AuthorityProof<ServiceAuth>,
     ) -> Result<()> {
         let required_space = std::mem::size_of::<RegisterCmd>() as u64;
         if !self.used_space.can_consume(required_space).await {
@@ -129,12 +126,12 @@ impl RegisterStorage {
         }
         let op = RegisterCmd {
             write,
-            client_sig: data_auth.clone().into_inner(),
+            auth: auth.clone().into_inner(),
         };
-        self.apply(op, data_auth)
+        self.apply(op, auth)
     }
 
-    fn apply(&self, op: RegisterCmd, data_auth: Authority<DataSigned>) -> Result<()> {
+    fn apply(&self, op: RegisterCmd, auth: AuthorityProof<ServiceAuth>) -> Result<()> {
         let RegisterCmd { write, .. } = op.clone();
 
         let address = *write.address();
@@ -171,9 +168,9 @@ impl RegisterStorage {
                                 ));
                             }
                             // TODO - Register::check_permission() doesn't support Delete yet in safe-nd
-                            // register.check_permission(action, Some(client_sig.public_key))?;
-                            if data_auth.public_key != entry.state.owner() {
-                                Err(Error::InvalidOwner(data_auth.public_key))
+                            // register.check_permission(action, Some(auth.public_key))?;
+                            if auth.public_key != entry.state.owner() {
+                                Err(Error::InvalidOwner(auth.public_key))
                             } else {
                                 info!("Deleting Register");
                                 let _ = self.db.drop_tree(key)?;
@@ -215,7 +212,7 @@ impl RegisterStorage {
                 info!("Editing Register");
                 entry
                     .state
-                    .check_permissions(Action::Write, Some(data_auth.public_key))?;
+                    .check_permissions(Action::Write, Some(auth.public_key))?;
                 let result = entry.state.apply_op(reg_op).map_err(Error::NetworkData);
 
                 if result.is_ok() {
@@ -392,7 +389,7 @@ impl Display for RegisterStorage {
 mod test {
     use super::RegisterOpStore;
     use crate::messaging::data::{RegisterCmd, RegisterWrite};
-    use crate::messaging::DataSigned;
+    use crate::messaging::ServiceAuth;
     use crate::node::Result;
 
     use crate::node::Error;
@@ -439,12 +436,12 @@ mod test {
 
         let write = RegisterWrite::New(replica1);
 
-        let client_sig = DataSigned {
+        let auth = ServiceAuth {
             public_key: pk,
             signature: authority_keypair1.sign(b""),
         };
 
-        let cmd = RegisterCmd { write, client_sig };
+        let cmd = RegisterCmd { write, auth };
 
         store.append(cmd.clone())?;
 
